@@ -1,14 +1,14 @@
 import argparse
 import sys
+from pathlib import Path
 from typing import Text
 
+config_location = Path().home() / ".ipython/nbextensions/jupyter-cogram"
+token_file_name = "cogram_auth_token"
+log_file_name = "cogram_access_log"
+
 
 def install_token(token: Text) -> None:
-    from pathlib import Path
-
-    config_location = Path().home() / ".ipython/nbextensions/jupyter-cogram"
-    token_file_name = "cogram_auth_token"
-
     loc = config_location.absolute()
 
     if not loc.is_dir():
@@ -21,6 +21,12 @@ def install_token(token: Text) -> None:
     print(f"Successfully stored API token at '{p}' 🎉")
 
 
+def add_log_file() -> None:
+    p = config_location.absolute() / log_file_name
+    if not p.is_file():
+        p.touch()
+
+
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description="Set your Cogram API token")
     parser.add_argument(
@@ -42,5 +48,6 @@ if __name__ == "__main__":
     # noinspection PyBroadException
     try:
         install_token(token)
+        add_log_file()
     except Exception as e:
         print("⚠️  Could not install token:\n{e}")
